-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

-- tab 5

local addonName, addonTable = ...
local L = addonTable.L
local T = addonTable.T
local AddColor = addonTable.AddColor

local addon = PriorityList
local wishlist = addon.WishListFunctions
local menus = addon.MenuFunctions
local items = addon.ItemFunctions
local comm  = addon.CommFunctions
local chars = addon.CharFunctions
local constructors = addon.Constructors

local listbox, dd_sender, dd_char
local sel_sender, sel_import_char

local function selectSender(sender, no_refresh)
 
 if not addon.import_list[sender] then
  sel_sender = ""
  dd_sender:SetText("")
  for k in pairs(addon.import_list) do
   selectSender(k)
   return
  end
  return
 end

 sel_sender = sender

 dd_sender:SetText(sender)

 dd_char.elements = addon.import_list[sel_sender]
 
 addon:Fire("SENDER_SELECTED", sender)
 
 if not no_refresh then addon:Refresh() end
end

local function selectImportChar(name, no_refresh)
 
 if not addon.import_list[sel_sender] then
  sel_import_char = ""
  dd_char:SetText("")
  addon:Refresh() 
  return
 elseif not addon.import_list[sel_sender][name] then
  sel_import_char = ""
  dd_char:SetText("")
  for k in pairs(addon.import_list[sel_sender]) do
   selectImportChar(k)
   return
  end
  addon:Refresh() 
  return
 end
 sel_import_char = name

 dd_char:SetText(name)

 addon:Fire("IMPORT_CHAR_SELECTED", name)
 
 if not no_refresh then addon:Refresh() end
end

local function deleteSender()
 if not sel_sender or sel_sender == "" then return end
 addon.import_list[sel_sender] = nil
 sel_sender = ""
 sel_char = ""
 dd_char:SetText("")
 dd_sender:SetText("")
 listbox:update()
end

local function importChar(name)
 if not name then return end
 
 PLWish_List[name] = nil
 chars:New(name)

 local imp = addon.import_list[sel_sender][name]
 for diff = 1,3 do
  if imp[diff].lists then PLWish_List[name][diff].lists  = imp[diff].lists end
  if imp[diff].looted then PLWish_List[name][diff].looted = imp[diff].looted end
 end
 addon.import_list[sel_sender][name] = nil
 local found
 for _ in pairs(addon.import_list[sel_sender]) do found = true break end
 if not found then
  addon.import_list[sel_sender] = nil
  sel_sender = ""
  sel_import_char = ""
  dd_char:SetText("")
  dd_sender:SetText("")
  listbox:update()
 else
  selectImportChar("")
 end
end

local function importSender()
 if not sel_sender or sel_sender == "" then return end
 
 for k in pairs(addon.import_list[sel_sender]) do
  importChar(k)
 end
end

local function hasChanges(name)
 if not addon.import_list[sel_sender] or not addon.import_list[sel_sender][name] then return end
 
 local t = addon.import_list[sel_sender][name]

 if PLWish_List[name] then
  for diff = 1,3 do
   for list = 1,3 do
    -- lists
    local t2 = PLWish_List[name][diff].lists[list]
    for k,v in pairs(t[diff].lists[list]) do
     if t2 and v ~= t2[k] then
	  return AddColor("*", "LIGHT_GREEN")
	 end
    end
	-- looted
	t2 = PLWish_List[name][diff].looted
    for k,v in pairs(t[diff].looted) do
     if t2 and v ~= t2[k] then
	  return AddColor("*", "LIGHT_GREEN")
	 end
    end
   end
  end
 else
  return AddColor("*", "LIGHT_GREEN")
 end
 return ""
end

local function updateListButton(self, list, index)
 local itemID = list[index]
 local t = addon.import_list[sel_sender] and addon.import_list[sel_sender][sel_import_char]
 local looted = t and t[addon.sel_difficulty].looted and t[addon.sel_difficulty].looted[itemID]
 
 if not itemID then return false end

 local Iname, _, Iquality, _, _, _, _, _, IequipSlot, Itexture = items:GetItemInfo(itemID) -- import data
 local isWishlist, Wdifficulty, Windex, Wlooted = chars:FindItem(sel_import_char, itemID, addon.sel_difficulty)

 local _,_,_,c = GetItemQualityColor(Iquality or 1)

 local isImport
 local t = addon.import_list[sel_sender] and addon.import_list[sel_sender][sel_import_char]
 if t and t[addon.sel_difficulty] and t[addon.sel_difficulty].lists and t[addon.sel_difficulty].lists[addon.sel_list] then
  isImport = tContains(t[addon.sel_difficulty].lists[addon.sel_list], itemID)
 end
 self.t = "item"
 self.s_topright:SetText("")
 self.s_bottomleft:SetText("")
 self.s_bottomright:SetText("")
 self.s_center:SetText("")
 self.lefticon:SetTexture()
 self.righticon:SetTexture()
 self.centericon:Show()
 self.centericon:SetTexture()
 if not Iname then
  self.lefticon:SetTexture("Interface\\ICONS\\Ability_Mage_TimeWarp")
  self.s_topleft:SetText(AddColor(L["receiving_item_info"], "GOLD"))
 else
  if looted then
   self.link = looted.link
  elseif Wlooted then
   self.link = Wlooted.link
  else
   self.link = items:GenerateLink(itemID, Iname, Iquality, addon.sel_difficulty)
  end

  local s_looted = ""
  if looted and Wlooted and looted.link == Wlooted.link  then
   s_looted = AddColor(L["looted"], "GRAY")
  elseif looted and not Wlooted then
   s_looted = AddColor("+"..L["looted"], "LIGHT_GREEN")
  elseif not looted and Wlooted then
   s_looted = AddColor("-"..L["looted"], "LIGHT_RED")
  end

  if isWishlist and isImport then -- look for changes
   local import_index
   for k,v in pairs(t[addon.sel_difficulty].lists[addon.sel_list]) do
    if v == itemID then 
	 import_index = k
	 break
	end
   end
   if Windex > import_index then
    self.s_center:SetText(AddColor("+"..math.abs(Windex - import_index), "LIGHT_GREEN"))
	self.centericon:SetRotation(PI)
	self.centericon:SetTexture(T["arrowup"])
	self.centericon:Show()
   elseif Windex < import_index then
    self.s_center:SetText(AddColor("-"..math.abs(Windex - import_index), "LIGHT_RED"))
	self.centericon:SetRotation(0)
	self.centericon:SetTexture(T["arrowdown"])
	self.centericon:Show()
   else
    self.s_center:SetText("")
   end
   self.lefticon:SetTexture(Itexture)
   self.s_topleft:SetText((c and ("|c"..c) or "")..Iname.."|r")
   self.righticon:Hide()
   --self.righticon:SetTexture(Itexture)
   --self.s_topright:SetText((c and ("|c"..c) or "")..Iname.."|r")
   self.s_bottomleft:SetText(s_looted)
  elseif not isWishlist and isImport then -- to be added item
   self.lefticon:SetTexture(Itexture)
   self.righticon:SetTexture(T["added"])
   self.s_topleft:SetText((c and ("|c"..c) or "")..Iname.."|r")
   --self.s_topright:SetText(L["added"])
   self.s_center:SetText(L["added"])
   self.s_bottomleft:SetText(s_looted)
  else -- to be deleted item
   self.lefticon:SetTexture(T["deleted"])
   self.righticon:SetTexture(Itexture)
   self.s_topright:SetText((c and ("|c"..c) or "")..Iname.."|r")
   self.s_topleft:SetText(ACTION_SPELL_AURA_REMOVED)
   self.s_bottomright:SetText(s_looted)
  end
 end
 return true
end

local list = {}
function listboxUpdate(self)
 wipe(list)

 local looted
 -- add the imported items the list
 local t = addon.import_list[sel_sender] and addon.import_list[sel_sender][sel_import_char]
 if t and t[addon.sel_difficulty] and t[addon.sel_difficulty].lists[addon.sel_list] then
  for i = 1, #t[addon.sel_difficulty].lists[addon.sel_list] do
   list[i] = t[addon.sel_difficulty].lists[addon.sel_list][i]
  end
  looted = t[addon.sel_difficulty].looted
 end
 
 -- check for deleted items 
 if PLWish_List[sel_import_char] then
  for i = 1, #PLWish_List[sel_import_char][addon.sel_difficulty].lists[addon.sel_list] do
   if not tContains(list, PLWish_List[sel_import_char][addon.sel_difficulty].lists[addon.sel_list][i]) then
    table.insert(list, PLWish_List[sel_import_char][addon.sel_difficulty].lists[addon.sel_list][i])
   end
  end
 end
 
 if #list <= 0 then
  return
 end

 self.list = list
end

local function dd_update_sender_button(self, list, index)
 self.left_text:SetText(list[index])
end

local function dd_update_sender_pre(self)
 wipe(self.list)
 for k,v in pairs(addon.import_list) do
  self.list[#self.list + 1] = k
 end
 table.sort(self.list, addon.sort)
end

local function dd_update_importchar_pre(self)
 wipe(self.list)
 if not addon.import_list[sel_sender] then return end
 
 for k,v in pairs(addon.import_list[sel_sender]) do
  self.list[#self.list + 1] = k
 end
 table.sort(self.list, addon.sort)
end

function addon.PLTab3Show(p)

 local ng = NyxGUI("1.0")

 if not p.initialized then
  p.initialized = true
  
  -- listbox
  local f = ng:New(addonName, "Listbox", "PLImportListbox", p)
  local bg_model = CreateFrame("Model", nil, f)
  bg_model:SetModel("interface\\glues\\models\\ui_mainmenu_northrend\\ui_mainmenu_northrend.m2")
  bg_model:SetAllPoints()
  bg_model:SetFrameStrata(f:GetFrameStrata())
  bg_model:SetFrameLevel(f:GetFrameLevel())
  f.list = {}

  f.update_pre = listboxUpdate
  f.update_button = updateListButton
  f:SetPoint("TOPLEFT", 10, -75)
  f:SetPoint("BOTTOMRIGHT", -30, 10)
  f:Initialize("PLListButtonTemplate")
  f.hideSelection = true
 
  for k,v in pairs(f.buttons) do
   v:SetFrameStrata(f:GetFrameStrata())
   v:SetFrameLevel(f:GetFrameLevel() + 2)
   v:SetScript("OnEnter", listButtonOnEnter)
   v:SetScript("OnLeave", listButtonOnLeave)
   v:SetBackdropColor(0,0,0,0.6)
   v:SetBackdropBorderColor(0,0,0,0)
  end
  
  listbox = f
 
  -- import sender dropdown
  f = ng:New(addonName, "Dropdown", "PLDDSender", p)
  f:SetWidth(150)
  f:SetPoint("TOPLEFT", p, "TOPLEFT", 10, -40)
  f:SetText(addon.sel_char)
  f.list = {}
  f.update_button = dd_update_sender_button
  f.update_pre = dd_update_sender_pre
  f.OnValueChanged = function(self, v) 
                      selectSender(self.list[self.index])
                     end
  f:Initialize()
  f:SetText("")
  
  f.title = ng:New(addonName, "Label", nil, f)
  f.title:SetPoint("BOTTOMLEFT", f, "TOPLEFT", 0, 1)
  f.title:SetText((L["sender"]))

  dd_sender = f
 
  -- import character dropdown
  f = ng:New(addonName, "Dropdown", "PLDDImportChar", p)
  f:SetWidth(150)
  f:SetPoint("LEFT", PLDDSender, "RIGHT", 210, 0)
  f:SetText("")
  f.list = {}
  f.update_button = dd_update_sender_button
  f.update_pre = dd_update_importchar_pre
  f.OnValueChanged = function(self, v) 
                      selectImportChar(self.list[self.index])
                     end
  f:Initialize()
  dd_char = f
  
  f.title = ng:New(addonName, "Label", nil, f)
  f.title:SetPoint("BOTTOMLEFT", f, "TOPLEFT", 0, 1)
  f.title:SetText((CHARACTER))

  -- import sender button
  f = constructors:RectButton("PLImportSenderBtn", p)
  f:SetPoint("BOTTOM", dd_sender, "TOP", 0, 2)
  f:SetSize(40,20)
  f:SetText(L["import"])
  f:SetScript("OnClick", function()
   importSender(sel_sender)
  end)
  
  -- delete sender button
  f = constructors:RectButton("PLDelSenderBtn", p)
  f:SetPoint("BOTTOMRIGHT", dd_sender, "TOPRIGHT", 0, 2)
  f:SetSize(40,20)
  f:SetText(DELETE)
  f:SetScript("OnClick", function()
   deleteSender()
   
  end)
  
  -- import char button
  f = constructors:RectButton("PLImportCharBtn", p)
  f:SetPoint("BOTTOM", dd_char, "TOP", 15, 2)
  f:SetSize(40,20)
  f:SetText(L["import"])
  f:SetScript("OnClick", function()
   importChar(sel_import_char)
  end)
  
  addon:Hook("PRIO_CHANGED", function() if listbox:IsVisible() then listbox:update() end end)
                                
  addon:Hook("LIST_IMPORTED", function(name)
                                 selectSender(name)
                                 if listbox:IsVisible() then
                                  listbox:update()
                                 end
                                end)
 end

 PLWLBtnList1:SetParent(p)
 PLWLBtnList2:SetParent(p)
 PLWLBtnList3:SetParent(p)
 listbox:update()
end