-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

local addonName, addonTable = ...
local addon = PriorityList

local L = addonTable.L

local ng = NyxGUI("1.0")

local constructors = addon.Constructors
local items = addon.ItemFunctions
local menus = addon.MenuFunctions

local numTabs        = 8
addon.sel_tab        = 1
addon.sel_difficulty = 1
addon.sel_list       = 1

local diff_buttons

function addon:SelectDiff(i, no_refresh)
 addon.sel_difficulty = i
 for k = 1,3 do
  local btn = _G["PLBtnDifficulty"..k]
  if k == i then 
   btn:LockHighlight()
  else
   btn:UnlockHighlight()
  end
 end
 pl_options["last_difficulty"] = addon.sel_difficulty
 addon:Fire("DIFF_SELECTED", i)
 if not no_refresh then addon:Refresh() end
end

function addon:SelectList(i, no_refresh)
 addon.sel_list = i
 addon:Fire("LIST_SELECTED", i)
 if not no_refresh then addon:Refresh() end
end

function addon:SelectChar(name, no_refresh)
 
 if not name or not PLWish_List[name] then
  addon.sel_char = ""
  addon:Fire("CHAR_SELECTED", "")
  for k in pairs(PLWish_List) do
   addon:SelectChar(k)
   return
  end
  return
 end

 addon.sel_char = name

 addon:Fire("CHAR_SELECTED", name)
 
 if not no_refresh then addon:Refresh() end
end

function addon:Refresh()
 addon:GeneratePrio()
end

function addon:Hook(event, func)
 if not addon.events[event] then
  addon.events[event] = {}
 end
 
 addon.events[event][#addon.events[event] + 1] = func
end

function addon:Fire(event, ...)
 if not addon.events[event] then return end

 for k,v in pairs(addon.events[event]) do
  v(...)
 end
end

function addon:createMainframe()
 local f = ng:New(addonName, "Frame", "PLMainframe", UIParent)
 ng:SetFrameMovable(f, true)
 f:SetSize(800,550)
 f:SetMinResize(800,300)
 f:SetPoint("CENTER")
 f:SetFrameStrata("HIGH")
 --f:SetScript("OnMouseUp", function(self, button) if button == "RightButton" then PLMainframe:Hide() end end)
 --f:SetClampedToScreen(true)
 
 --f.logo = f:CreateTexture()
 --f.logo:SetPoint("TOP", f, "TOP", 0, -10)
 --f.logo:SetSize(200,45)
 --f.logo:SetTexture("Interface\\Addons\\PriorityList\\logo.tga")
 
 f.logo = f:CreateFontString(nil, nil, "SystemFont_OutlineThick_Huge4")
 f.logo:SetPoint("TOP", f, "TOP", 0, -20)
 f.logo:SetText("Priority List 3")

 addon.frames.main = f
 
  -- difficulty buttons
 local function btndiff_onclick(self)
  addon:SelectDiff(self.tag)
  addon:Refresh()
 end

 diff_buttons = {}
 -- normal
 f = ng:New(addonName, "Button", "PLBtnDifficulty1", PLMainframe)
 f.tag = 1
 f:SetSize(50,35)
 f:SetPoint("TOPLEFT", PLMainframe, "TOPLEFT", 20, -20)
 f:SetText(L["difficulty1"])
 f:SetScript("OnClick", btndiff_onclick)
 diff_buttons[1] = f
 -- heroic
 f = ng:New(addonName, "Button", "PLBtnDifficulty2", PLMainframe)
 f.tag = 2
 f:SetSize(50,35)
 f:SetPoint("LEFT", PLBtnDifficulty1, "RIGHT", 10, 0)
 f:SetText(L["difficulty2"])
 f:SetScript("OnClick", btndiff_onclick)
 diff_buttons[2] = f
 -- mythic
 f = ng:New(addonName, "Button", "PLBtnDifficulty3", PLMainframe)
 f.tag = 3
 f:SetSize(50,35)
 f:SetPoint("LEFT", PLBtnDifficulty2, "RIGHT", 10, 0)
 f:SetText(L["difficulty3"])
 f:SetScript("OnClick", btndiff_onclick)
 diff_buttons[3] = f

 addon:Hook("DIFF_SELECTED", function(i) 
                              for k,v in pairs(diff_buttons) do
                               if k == i then 
                                v:setHighlightAlpha(0.5)
                                v.lockedhighlight = true
                               else
                                v:setHighlightAlpha(0)
                                v.lockedhighlight = false
                               end
                              end
                            end)
 
 -- close buttons
 f = ng:New(addonName, "Button", "PLClosebtn", PLMainframe)
 f:SetSize(75,25)
 f:SetPoint("BOTTOM", PLMainframe, "BOTTOM", 0, 10)
 f:SetScript("OnClick", function() PLMainframe:Hide() end)
 f:SetText(CLOSE)
 
 f = ng:New(addonName, "Button", "PLClosebtn2", PLMainframe)
 f:SetSize(25,25)
 f:SetPoint("TOPRIGHT", -1, -1)
 f:SetScript("OnClick", function() PLMainframe:Hide() end)
 f:SetText("X")
  
 menus:PopupInit(f)
 
 -- tab anchor
 local anchor = ng:New(addonName, "Groupbox", "PLMainframeTabAnchor", PLMainframe)
 anchor:SetPoint("TOPLEFT", PLMainframe, "TOPLEFT", 20, -100)
 anchor:SetPoint("BOTTOMRIGHT", PLMainframe, "BOTTOMRIGHT", -20, 50)

 local function create_tab(i, text)
  local f = ng:New(addonName, "Tabbutton", "PLTab"..i, anchor)
  f:SetHeight(20)
  f:SetText(text)
  if addon["PLTab"..i.."Show"] then
   f.tab:SetScript("OnShow", addon["PLTab"..i.."Show"])
  else
   f:EnableMouse(false)
  end
  return f
 end
 
 -- wishlist tab button
 f = create_tab(1, L["wishlist"])
 
 -- looted tab button
 f = create_tab(2, L["looted"])
 
  -- itemslist tab button
 --f = create_tab(3, ITEMS)

  -- bosslist tab button
 --f = create_tab(4, BOSS)
 
 -- import tab button
 f = create_tab(3, L["import"])
 
 -- messages tab button
 --f = create_tab(6, HISTORY)

 -- options tab button
 f = create_tab(4, GAMEOPTIONS_MENU)
 
 -- help tab button
 --f = create_tab(8, GAMEMENU_HELP)
 
 addon:SelectChar(UnitName("player"), true)
 addon:SelectList(1, true)
 addon:SelectDiff(pl_options["last_difficulty"] or 1, true)
 PLTab1:Click()
end