-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

-- tab 7

local tinsert = table.insert

local addonName, addonTable = ...
local L = addonTable.L
local C = addonTable.C

local addon = PriorityList
local comm = addon.CommFunctions
local wishlist = addon.WishListFunctions
local menus = addon.MenuFunctions
local items = addon.ItemFunctions
local chars = addon.CharFunctions
local constructors = addon.Constructors
local dialogs = addon.Dialogs

local SURadar = {}

local function onShow()
 if addon:IsSuperUser() then
  PLOptGrpSU.text:SetText(L["superuser"].." ("..addon.guildname..")")
  PLOptGrpVal:Show()
  PLOptGrpWish:Show()
  PLOptGrpSU:Show()
 else
  PLOptGrpVal:Hide()
  PLOptGrpWish:Hide()
  PLOptGrpSU:Hide()
 end
 PLListbox:Hide()
end

local function onHide()

end

function clearLists()
 local func = function() chars:ClearLists(addon.playername, addon.sel_difficulty) end
 dialogs:Confirm(func, true, string.format(L["confirm_wipe"], addon.playername, L["difficulty"..addon.sel_difficulty]))
end

function clearAllLists()
 local func = function() for k,v in pairs(PLWish_List) do chars:ClearLists(k, addon.sel_difficulty) end end
 dialogs:Confirm(func, true, string.format(L["confirm_wipe_all"], L["difficulty"..addon.sel_difficulty]))
end

function addon:SURadar_Add(name)
 if not tContains(SURadar, name) then
  tinsert(SURadar, name)
 end
end

function addon.PLTab4Show(p)
 
 if not p.initialized then
  p.initialized = true
  local ng = NyxGUI("1.0")
  local chk_width = 220
  
  local bg_model = CreateFrame("Model", nil, p)
  bg_model:SetModel("interface\\glues\\models\\ui_nightelf\\ui_nightelf.m2")
  bg_model:SetAllPoints()
  bg_model:SetFrameStrata(p:GetFrameStrata())
  bg_model:SetFrameLevel(p:GetFrameLevel())
  
  ------- general --------
  local grp_general = ng:New(addonName, "Groupbox", nil, p)
  grp_general:SetText(GENERAL)
  grp_general:SetSize(250, 180)
  grp_general:SetPoint("TOPLEFT", p, "TOPLEFT", 20, -20)
  
  -- tooltip extension checkbox
  f = ng:New(addonName, "Checkbox", nil, grp_general)
  f:SetPoint("TOPLEFT", grp_general, "TOPLEFT", 5, -2)
  f:SetText(L["opt_ttextension"])
  f:SetChecked(pl_options["ttlinkbtn"])
  f:SetScript("OnClick", function(self)
   pl_options["ttlinkbtn"] = self:GetChecked() and true or false
  end)
  
  -- confirm changes checkbox
  f = ng:New(addonName, "Checkbox", nil, grp_general)
  f:SetPoint("TOPLEFT", grp_general, "TOPLEFT", 5, -22)
  f:SetText(L["opt_confirm"])
  f:SetChecked(pl_options["confirm_edit"])
  f:SetScript("OnClick", function(self)
   pl_options["confirm_edit"] = self:GetChecked() and true or false
  end)
  
  --[[ autosync checkbox
  f = constructors:Checkbox(grp_general, chk_width, L["autosync"])
  f:SetPoint("TOPLEFT", grp_general, "TOPLEFT", 5, -42)
  f:SetChecked(pl_options["autosync"])
  f:SetScript("OnClick", function(self)
   pl_options["autosync"] = self:GetChecked() and true or false
  end)
  ]]
  
  -- clear lists button
  f = constructors:RectButton("PLOptClearList", grp_general)
  f:SetPoint("BOTTOMLEFT", grp_general, "BOTTOMLEFT", 2, 2)
  f:SetSize(100,25)
  f:SetText(L["clearlists"])
  f:SetScript("OnClick", clearLists)
  
  -------------------------
  
  if not addon:IsSuperUser() then return end
  
  ------- wishlist --------
  local grp_wishlist = ng:New(addonName, "Groupbox", "PLOptGrpWish", p)
  grp_wishlist:SetText(L["wishlist"])
  grp_wishlist:SetSize(250, 180)
  grp_wishlist:SetPoint("TOPLEFT", grp_general, "TOPRIGHT", 5, 0)
  
  -- short looted names checkbox
  f = ng:New(addonName, "Checkbox", nil, grp_wishlist)
  f:SetText(L["opt_shortnames"])
  f:SetPoint("TOPLEFT", grp_wishlist, "TOPLEFT", 5, -2)
  f:SetChecked(pl_options["short_looted_names"])
  f:SetScript("OnClick", function(self)
   pl_options["short_looted_names"] = self:GetChecked() and true or false
  end)
  
  -- show all chars checkbox
  f = ng:New(addonName, "Checkbox", nil, grp_wishlist)
  f:SetText(L["opt_showallchars"])
  f:SetPoint("TOPLEFT", grp_wishlist, "TOPLEFT", 5, -22)
  f:SetChecked(pl_options["show_all_chars"])
  f:SetScript("OnClick", function(self)
   pl_options["show_all_chars"] = self:GetChecked() and true or false
  end)
  
  -- clear ALL lists button
  f = constructors:RectButton("PLOptClearALLLists", grp_wishlist)
  f:SetPoint("BOTTOMLEFT", grp_wishlist, "BOTTOMLEFT", 2, 2)
  f:SetSize(100,25)
  f:SetText(L["clearALLlists"])
  f:SetScript("OnClick", clearAllLists)
  
  -------- values ---------
  local grp_values = ng:New(addonName, "Groupbox", "PLOptGrpVal", p)
  grp_values:SetPoint("TOPLEFT", grp_wishlist, "TOPRIGHT", 5, 0)
  grp_values:SetText(L["bID_values"])
  grp_values:SetSize(180, 180)
  
  local function onValueChanged(self, value)
   local v = math.floor(value * 10) / 10
   self:SetValue(v)
   pl_options["bonus_value_"..self.tag] = v
   self.text_value:SetText(v)
  end
  
  for i = 1,C.numBonuses do
   f = ng:New(addonName, "SliderH", "PLBonusSlider"..i, grp_values)
   f:SetPoint("TOPLEFT", grp_values, "TOPLEFT", 15, -11 - (i - 1) * 35)
   f:SetText(L["bonus"..i])
   f.onValueChanged = onValueChanged
   f:SetMinMaxValues(0, 1)
   f:SetValueStep(0.05)
   f.tag = i
   f:SetValue(pl_options["bonus_value_"..i])
  end
  -------------------------
  
  ------- SuperUser --------
  local grp_su = ng:New(addonName, "Groupbox", "PLOptGrpSU", p)
  grp_su:SetPoint("TOPLEFT", grp_general, "BOTTOMLEFT", 0, -20)
  grp_su:SetText(L["superuser"])
  grp_su:SetSize(250, 180)
  
  -- give SuperUser editbox
  f = constructors:EditBox(grp_su, L["opt_su_give"])
  f:SetScript("OnEnterPressed", function(self) comm.SetSuperUser(self:GetText()) end)
  f:SetPoint("TOPLEFT", grp_su, "TOPLEFT", 5, -15)
  
  -- remove SuperUser editbox
  f = constructors:EditBox(grp_su, L["opt_su_remove"])
  f:SetScript("OnEnterPressed", function(self) comm.RemoveSuperUser(self:GetText()) end)
  f:SetPoint("TOPLEFT", grp_su, "TOPLEFT", 5, -65)
  
  -- SuperUser radar
  f = constructors:RectButton("PL3OptSURadar", grp_su)
  f:SetPoint("TOPRIGHT", grp_su, "TOPRIGHT", -5, -5)
  f:SetText(L["radar"])
  f:SetScript("OnEnter", function(self)
   GameTooltip:SetOwner(self, "LEFT")
   GameTooltip:ClearLines()
   for k,v in pairs(SURadar) do
    GameTooltip:AddLine(v)
   end
   GameTooltip:Show()
  end)
  
  f:SetScript("OnLeave", function() GameTooltip:Hide() end)
  f:SetScript("OnClick", function() wipe(SURadar) comm:FindSuperUsers() end)
 end

  --[[
  f = constructors:RectButton("PL3TMPConvertButton", PLTabFrame7)
  f:SetPoint("BOTTOMRIGHT", PLMainframeTabAnchor, "BOTTOMRIGHT")
  f:SetSize(200,25)
  f:SetText("|cffFF0000<DEBUG>|r Importa liste da PL2")
  f:SetScript("OnClick", addon.ConvertPL2Lists)
  ]]
  
  --[[----- autosync ------
  local grp_sync = constructors:Groupbox(PLTabFrame7, nil, 180, 180, L["autosync"])
  grp_sync:SetPoint("TOPLEFT", grp_general, "TOPRIGHT", 5, 0)
  
  -- enable checkbox
  f = constructors:Checkbox(grp_sync, ENABLE)
  f:SetPoint("TOPLEFT", grp_sync, "TOPLEFT", 5, -2)
  f:SetChecked(pl_options["autosync"])
  f:SetScript("OnClick", function(self) 
   pl_options["autosync"] = self:GetChecked() and true or false
  end)
  
  -- officers
  for i = 1,3 do
   f = constructors:EditBox(grp_sync, "Officer "..i, function(self) pl_options["officer"..self.tag] = self:GetText() end)
   f.tag = i
   f:SetPoint("TOPLEFT", grp_sync, "TOPLEFT", 5, -45 * i - 5)
   f:SetWidth(150)
   f:SetText(pl_options["officer"..i] or "")
  end
  ]]-------------------------
  
  
  -- 3 o 4 editboxes per settare il nome degli officer e automatizzare
  -- sincronia (gli officer sincronizzano le liste dei vari pg)
  -- i pg comunicano loot personali 
end