-- Priority List 3
-- by Jadya
-- EU-Well of Eternity

-- tab 1

local addonName, addonTable = ...
local L = addonTable.L
local C = addonTable.C
local T = addonTable.T
local AddColor = addonTable.AddColor

local addon = PriorityList
local items = addon.ItemFunctions
local constructors = addon.Constructors
local dialogs = addon.Dialogs
local chars = addon.CharFunctions
local comm = addon.CommFunctions

local listbox, dd_char, list_buttons

local function updateListButton(f, list, index)

 if index > #list then return end

 f.t = "item"

 local itemID = list[index]
 local name, link, quality, _, _, _, _, _, equipSlot, texture = items:GetItemInfo(itemID)

 f.s_bottomleft:SetText("")
 f.s_topright:SetText("")
 f.s_bottomright:SetText("")
 f.s_center:SetText("")
 f.centericon:Hide()
 f.background:SetVertexColor(0,0,0,0)
 f.itemID = itemID
 local looted = chars:GetLootedItem(addon.sel_char, addon.sel_difficulty, itemID)
 local bonuses, itemlevel
 if name and looted then
  link = looted.link
  bonuses = items:ExtractBonuses(link)
  itemlevel = looted.itemlevel
  if looted.personal then
   f.background:SetVertexColor(0.2,1,0.6,0.1)
  else
   f.background:SetVertexColor(0.2,0.6,1,0.1)
  end
 end
 if not link then
  f.lefticon:SetTexture("Interface\\ICONS\\Ability_Mage_TimeWarp")
  f.s_topleft:SetText(AddColor(L["receiving_item_info"], "GOLD"))
 else
  f.link = looted and link or items:GenerateLink(itemID, name, quality, addon.sel_difficulty)
  f.lefticon:SetTexture(texture)
  local bns = items:GetBonusString(bonuses, true)
  f.s_topright:SetText((looted and AddColor(L["looted"]..(bns ~= "" and " -"..bns or ""), "LIGHT_BLUE") or ""))
  local _,_,_,c = GetItemQualityColor(quality or 1)
  f.s_topleft:SetText((c and ("|c"..c) or "")..name.."|r")
  local prio = addon.prio[addon.sel_difficulty][itemID]
  local info = ""
  if prio then
   local last_prio
   for k,v in pairs(prio) do
    local list = math.ceil(v.prio / C.PRIO_GAP)
	local isLooted = chars:GetLootedItem(v.name, addon.sel_difficulty, itemID)
	local s = isLooted and AddColor(--[[v.prio..]](pl_options["short_looted_names"] and v.name:sub(1,4) or v.name), "LIGHT_BLUE") or AddColor(v.name, C.list_color[list])
    if last_prio and last_prio == v.prio then
	 info = info..AddColor("\\", "LIGHT_GREEN")..s
	else
     info = info..(k > 1 and " " or "")..s
	end
	last_prio = v.prio
   end
  end
  f.s_bottomleft:SetText(info)
  f.s_bottomright:SetText("")
 end

 return true
end

local function listboxUpdate(self)
 local list = chars:GetList(addon.sel_char, addon.sel_list, addon.sel_difficulty)
 self.list = list
end

local function buttonDragStart(self)
 PickupItem(self.link or 1)
 if self.itemID and not IsControlKeyDown() then
  chars:DeleteItem(addon.sel_char, self.itemID, addon.sel_list, addon.sel_difficulty, true)
 end
end

local function listboxDragReceive(self)
 local t, itemID = GetCursorInfo()
 if t == "item" then
  chars:AddItem(addon.sel_char, itemID, addon.sel_list, addon.sel_difficulty, true)
  ClearCursor()
 end
end

local function listboxMouseUp(self)
 local t, itemID = GetCursorInfo()
 if t == "item" then
  listboxDragReceive(self)
 end
end

local function buttonDragReceive(self)
 local t, itemID = GetCursorInfo()
 if t == "item" then
  local pos = self.index + HybridScrollFrame_GetOffset(PLListbox)
  chars:AddItem(addon.sel_char, itemID, addon.sel_list, addon.sel_difficulty, true, pos)
  ClearCursor()
 end
end

local function buttonMouseUp(self, button)
 if button == "LeftButton" then
  if IsShiftKeyDown() then
   -- link
  elseif IsAltKeyDown() and self.itemID then
   dialogs:LootedFlags(addon.sel_char, addon.sel_difficulty, self.itemID)
  else
   buttonDragReceive(self)
  end
 elseif button == "RightButton" and self.itemID and IsControlKeyDown() then
  chars:DeleteItem(addon.sel_char, self.itemID, addon.sel_list, addon.sel_difficulty, true)
 end
end

local function listButtonOnEnter(self)
 self:SetScript("OnEnter", function(self)
  if self.t == "item" and self.link then
   GameTooltip:SetOwner(self:GetParent(), "ANCHOR_RIGHT")
   GameTooltip:SetHyperlink(self.link)
   GameTooltip:Show()
  end
 end)
end

local function listButtonOnLeave(self)
 GameTooltip:Hide()
end

local function dd_update_button(self, list, index)
 self.left_text:SetText(list[index])
end

local function dd_update_pre(self)
 wipe(self.list)
 for k,v in pairs(PLWish_List) do
  self.list[#self.list + 1] = k
 end
 table.sort(self.list, addon.sort)
end

function addon.PLTab1Show(p)
 local ng = NyxGUI("1.0")

 if not p.initialized then
  p.initialized = true
  -- listbox
  local f = ng:New(addonName, "Listbox", "PLListbox", p)
  local bg_model = CreateFrame("Model", nil, f)
  bg_model:SetModel("interface\\glues\\models\\ui_demonhunter\\ui_demonhunter.m2")
  bg_model:SetAllPoints()
  bg_model:SetFrameStrata(f:GetFrameStrata())
  bg_model:SetFrameLevel(f:GetFrameLevel())
  f.bg_model = bg_model
  f.list = {}

  f.update_pre = listboxUpdate
  f.update_button = updateListButton
  f:SetScript("OnReceiveDrag", listboxDragReceive)
  f:SetScript("OnMouseUp", listboxDragReceive)
  f:SetPoint("TOPLEFT", 10, -75)
  f:SetPoint("BOTTOMRIGHT", -30, 10)
  f:Initialize("PLListButtonTemplate")
  f.hideSelection = true

  for k,v in pairs(f.buttons) do
   v:SetFrameStrata(f:GetFrameStrata())
   v:SetFrameLevel(f:GetFrameLevel() + 2)
   v:SetScript("OnEnter", listButtonOnEnter)
   v:SetScript("OnLeave", listButtonOnLeave)
   v:SetScript("OnMouseUp", buttonMouseUp)
   v:SetScript("OnReceiveDrag", buttonDragReceive)
   v:SetScript("OnDragStart", buttonDragStart)
   v:SetBackdropColor(0,0,0,0.6)
   v:SetBackdropBorderColor(0,0,0,0)
  end
  
  listbox = f
  
  addon:Hook("PRIO_CHANGED", function() if listbox:IsVisible() then listbox:update() end end)
  --

  -- characters dropdown
  f = ng:New(addonName, "Dropdown", "PLDDCharacters", p)
  f:SetWidth(150)
  f:SetPoint("TOPLEFT", p, "TOPLEFT", 10, -40)
  f:SetText(addon.sel_char)
  f.list = {}
  f.update_button = dd_update_button
  f.update_pre = dd_update_pre
  f.OnValueChanged = function(self, v) 
                      addon:SelectChar(self.list[self.index])
                     end
  f:Initialize()
  f:SetText(addon.sel_char or "")
  dd_char = f
  
  addon:Hook("CHAR_SELECTED", function(name)
                               dd_char:SetText(name)
                               if listbox:IsVisible() then listbox:update() end
                              end)
  
  -- new char button
  f = constructors:RectButton("PLTab1NewCharBtn", p)
  f:SetPoint("BOTTOMLEFT", dd_char, "TOPLEFT", 1, 2)
  f:SetSize(40,20)
  f:SetText(NEW)
  f:SetScript("OnClick", function()
   dialogs:NewChar()
  end)
  
  -- rename char button
  f = constructors:RectButton("PLTab1RenCharBtn", p)
  f:SetPoint("LEFT", PLTab1NewCharBtn, "RIGHT", 10, 0)
  f:SetSize(40,20)
  f:SetText(PET_RENAME)
  f:SetScript("OnClick", function()
   if PLWish_List[addon.sel_char] then
    dialogs:RenameChar(addon.sel_char)
   end
  end)
  
  -- delete char button
  f = constructors:RectButton("PLTab1DelCharBtn", p)
  f:SetPoint("LEFT", PLTab1RenCharBtn, "RIGHT", 10, 0)
  f:SetSize(40,20)
  f:SetText(CALENDAR_DELETE_EVENT)
  f:SetScript("OnClick", function()
   if PLWish_List[addon.sel_char] then
    chars:Delete(addon.sel_char, true)
   end
  end)
  
  -- list buttons
  local function btnlist_onclick(self)
   addon:SelectList(self.tag)
   addon:Refresh()
  end
  
  list_buttons = {}
  -- 1
  f = ng:New(addonName, "Button", "PLWLBtnList1", p)
  f.tag = 1
  f:SetSize(50,25)
  f:SetPoint("LEFT", dd_char, "RIGHT", 20, 0)
  f:SetText(L["list1"])
  f:SetScript("OnClick", btnlist_onclick)
  list_buttons[1] = f
  -- 2
  f = ng:New(addonName, "Button", "PLWLBtnList2", p)
  f.tag = 2
  f:SetSize(50,25)
  f:SetPoint("LEFT", PLWLBtnList1, "RIGHT", 10, 0)
  f:SetText(L["list2"])
  f:SetScript("OnClick", btnlist_onclick)
  list_buttons[2] = f
  -- 3
  f = ng:New(addonName, "Button", "PLWLBtnList3", p)
  f.tag = 3
  f:SetSize(50,25)
  f:SetPoint("LEFT", PLWLBtnList2, "RIGHT", 10, 0)
  f:SetText(L["list3"])
  f:SetScript("OnClick", btnlist_onclick)
  list_buttons[3] = f
  
  local function list_selected(i)
   for k,v in pairs(list_buttons) do
    if k == i then 
     v:setHighlightAlpha(0.5)
     v.lockedhighlight = true
    else
     v:setHighlightAlpha(0)
     v.lockedhighlight = false
    end
   end
  end
  
  addon:Hook("LIST_SELECTED", list_selected)
  list_selected(addon.sel_list)
  
  -- export button
  f = constructors:RectButton("PLWLBtnExport1", p)
  f:SetSize(75,25)
  f:SetPoint("LEFT", PLWLBtnList3, "RIGHT", 50, 0)
  f:SetText(L["export_all"])
  f:SetScript("OnClick", function() comm:LinkToChat("all") end)
  
 -- export button
  f = constructors:RectButton("PLWLBtnExport2", p)
  f:SetSize(75,25)
  f:SetPoint("LEFT", PLWLBtnExport1, "RIGHT", 10, 0)
  f:SetText(L["export_char"])
  f:SetScript("OnClick", function() comm:LinkToChat(addon.sel_char) end)
 end
 
 PLWLBtnList1:SetParent(p)
 PLWLBtnList2:SetParent(p)
 PLWLBtnList3:SetParent(p)
 dd_char:SetParent(p)
 listbox:update()
end